==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/weapon/TrumpetGun.java <==
package cc.thonly.reverie_dreams.item.weapon;

import cc.thonly.reverie_dreams.danmaku.DanmakuTrajectory;
import cc.thonly.reverie_dreams.danmaku.DanmakuTypes;
import cc.thonly.reverie_dreams.entity.misc.DanmakuEntity;
import cc.thonly.reverie_dreams.item.base.IDanmakuItem;
import cc.thonly.reverie_dreams.server.DelayedTask;
import cc.thonly.reverie_dreams.sound.SoundEventInit;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1796;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_3218;
import net.minecraft.class_3222;

public class TrumpetGun extends class_1792 implements IDanmakuItem {

    public TrumpetGun(class_1793 settings) {
        super(settings);
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        class_1799 stack = user.method_5998(hand);
        if (!world.method_8608() && user instanceof class_3222 player) {
            class_3218 serverWorld = (class_3218) world;
            float pitch = user.method_36455();
            float yaw = user.method_36454();
            DelayedTask.repeat(world.method_8503(), 3, 2, () -> {
                DanmakuEntity entity = DanmakuTrajectory.spawnByItemStack(serverWorld, user, user.method_23317(), user.method_23318(), user.method_23321(), DanmakuTypes.random(DanmakuTypes.BULLET), pitch, yaw, 1.4f, 0f, 0.0f, 1.5f);
                entity.method_5783(SoundEventInit.FIRE, 1.0f, 1.0f);
            });
            class_1796 itemCooldownManager = player.method_7357();
            itemCooldownManager.method_62835(stack, 35);
            if (!player.method_56992()) {
                stack.method_61653(1, player);
            }
            return class_1269.field_52422;
        }
        return super.method_7836(world, user, hand);
    }

}

==> reverie_dreams-0.4.7%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/weapon/TrumpetGun.java <==
package cc.thonly.reverie_dreams.item.weapon;

import cc.thonly.reverie_dreams.data.danmaku.DanmakuTrajectory;
import cc.thonly.reverie_dreams.registry.content.danmaku.DanmakuTypes;
import cc.thonly.reverie_dreams.entity.misc.DanmakuEntity;
import cc.thonly.reverie_dreams.item.base.IDanmakuItem;
import cc.thonly.reverie_dreams.server.DelayedTask;
import cc.thonly.reverie_dreams.sound.SoundEventInit;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1796;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_3218;
import net.minecraft.class_3222;

public class TrumpetGun extends class_1792 implements IDanmakuItem {

    public TrumpetGun(class_1793 settings) {
        super(settings);
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        class_1799 stack = user.method_5998(hand);
        if (!world.method_8608() && user instanceof class_3222 player) {
            class_3218 serverWorld = (class_3218) world;
            float pitch = user.method_36455();
            float yaw = user.method_36454();
            DelayedTask.repeat(world.method_8503(), 3, 2, () -> {
                DanmakuEntity entity = DanmakuTrajectory.spawnByItemStack(serverWorld, user, user.method_23317(), user.method_23318(), user.method_23321(), DanmakuTypes.random(DanmakuTypes.BULLET), pitch, yaw, 0.0f, 1.5f);
                entity.method_5783(SoundEventInit.FIRE, 1.0f, 1.0f);
            });
            class_1796 itemCooldownManager = player.method_7357();
            itemCooldownManager.method_62835(stack, 35);
            if (!player.method_56992()) {
                stack.method_61653(1, player);
            }
            return class_1269.field_52422;
        }
        return super.method_7836(world, user, hand);
    }

}
